@@ -5,8 +5,6 @@ use warnings;
 use Perl::Critic::Utils;
 use parent 'Perl::Critic::Policy';
 
-our $VERSION = '0.01';
-
 sub default_themes       { return qw( maintenance )     }
 sub applies_to           { return 'PPI::Document' }
 
@@ -14,28 +12,35 @@ sub applies_to           { return 'PPI::Document' }
 
 sub violates {
     my ( $self, $elem, $doc ) = @_;
-    my @violations = $self->gather_violations_trytiny($elem, $doc);
+    my @violations = $self->gather_violations_try_family($elem, $doc);
     push @violations, $self->gather_violations_objective($elem, $doc);
     return @violations;
 }
 
-sub gather_violations_trytiny {
+sub gather_violations_try_family {
     my ( $self, $elem, $doc ) = @_;
-    my @use_try_tiny = grep { $_->module eq 'Try::Tiny' } @{ $elem->find('PPI::Statement::Include') ||[] };
-    return () unless 0 < @use_try_tiny;
+
+    my @violations;
+
+    my @includes = @{ $elem->find('PPI::Statement::Include') ||[] };
+    return @violations unless @includes;
 
     my $has_try_block = 0;
-    for my $try_keyword (@{ $elem->find(sub { $_[1]->isa('PPI::Token::Word') && $_[1]->content eq "try" }) ||[]}) {
+    for my $try_keyword (@{ $elem->find(sub { $_[1]->isa('PPI::Token::Word') && $_[1]->content eq 'try' }) ||[]}) {
         my $try_block = $try_keyword->snext_sibling or next;
         next unless $try_block->isa('PPI::Structure::Block');
         $has_try_block = 1;
         last;
     }
-    return () if $has_try_block;
 
-    return map {
-        $self->violation("Unused Try::Tiny module", "There are no `try` block in the code.", $_);
-    } @use_try_tiny;
+    for my $try_module (qw(Try::Tiny Try::Catch Try::Lite TryCatch Try)) {
+        my @uses = grep { $_->module eq $try_module } @includes;
+        if (@uses && !$has_try_block) {
+            push @violations, map { $self->violation("Unused ${try_module} module", 'There are no `try` block in the code.', $_) } @uses;
+        }
+    }
+
+    return @violations;
 }
 
 sub gather_violations_objective {
@@ -75,7 +80,7 @@ TooMuchCode::ProhibitUnusedInclude -- Find unused include statements.
 
 This critic policy scans for unused include statement according to their documentation.
 
-For example, L<Try::Tiny> implicity introduce a C<try> subroutine that takes a block. There fore, A
+For example, L<Try::Tiny> implicity introduce a C<try> subroutine that takes a block. Therefore, a
 lonely C<use Try::Tiny> statement without a C<try { .. }> block somewhere in its scope is considered
 to be an "Unused Include".
 
